@@ -116,7 +116,7 @@ class DynamoDBBackend(Backend):
         self._boto3 = boto3
         self._environment = environment
         if not environment.get('AWS_REGION', True):
-            raise ValueError('To use DynamoDB you must use set the AWS_REGION environment variable')
+            raise ValueError('To use DynamoDB you must use set AWS_REGION in the .env file or an environment variable')
 
         self._dynamodb = self._boto3.resource('dynamodb', region_name=environment.get('AWS_REGION', True))
         self._table_indexes = {}
@@ -126,10 +126,20 @@ class DynamoDBBackend(Backend):
         pass
 
     def update(self, id, data, model):
+        # when we run an update column we must include the sort column on the primary
+        # index (if it exists)
+        sort_column_name = self._find_primary_sort_column(model)
+        key = {model.id_column_name: model.__getattr__(model.id_column_name)}
+        if sort_column_name:
+            key[sort_column_name] = data.get(
+                sort_column_name,
+                model.columns()[sort_column_name].to_backend(model._data)
+            )
         table = self._dynamodb.Table(model.table_name())
+
         updated = table.update_item(
-            Key={model.id_column_name: model.__getattr__(model.id_column_name)},
-            UpdateExpression=','.join([f"set {column_name} = :{column_name}" for column_name in data.keys()]),
+            Key=key,
+            UpdateExpression='SET ' + ', '.join([f"{column_name} = :{column_name}" for column_name in data.keys()]),
             ExpressionAttributeValues={
                 **{f':{column_name}': value
                    for (column_name, value) in data.items()},
@@ -158,7 +168,9 @@ class DynamoDBBackend(Backend):
                 next_page_data: Dict[str, str] = None) -> List[Dict[str, Any]]:
         response = self._dynamodb_query(configuration, model, 'ALL_ATTRIBUTES')
         if 'LastEvaluatedKey' in response and response['LastEvaluatedKey'] is not None and type(next_page_data) == dict:
-            next_page_data['next_token'] = self.serialize_next_token_for_response(response['LastEvaluatedKey'])
+            next_page_data['next_token'] = self.serialize_next_token_for_response(
+                self._map_from_boto3(response['LastEvaluatedKey'])
+            )
         return [self._map_from_boto3(item) for item in response['Items']]
 
     def _dynamodb_query(self, configuration, model, select_type):
@@ -478,6 +490,17 @@ class DynamoDBBackend(Backend):
         self._table_indexes[model.table_name()] = table_indexes
         return table_indexes
 
+    def _find_primary_sort_column(self, model):
+        indexes = self._get_indexes_for_model(model)
+        primary_indexes = indexes.get(model.id_column_name)
+        if not primary_indexes:
+            return None
+        for (column_name, index_name) in primary_indexes['sortable_columns'].items():
+            # the primary index doesn't have a name, so we want the record with a name of None
+            if index_name is None:
+                return column_name
+        return None
+
     def _map_from_boto3(self, record):
         return {key: self._map_from_boto3_value(value) for (key, value) in record.items()}
 
