@@ -1,10 +1,13 @@
 from clearskies.di import StandardDependencies as DefaultStandardDependencies
-from ..backends import DynamoDBBackend
+from ..backends import DynamoDBBackend, SqsBackend
 from ..secrets import ParameterStore
 class StandardDependencies(DefaultStandardDependencies):
     def provide_dynamo_db_backend(self, boto3, environment):
         return DynamoDBBackend(boto3, environment)
 
+    def provide_sqs_backend(self, boto3, environment):
+        return SqsBackend(boto3, environment)
+
     def provide_boto3(self):
         import boto3
         return boto3
